import unittest
import pathlib

class TestBase(unittest.TestCase):  # unittest.TestCaseを親クラスとした子クラスを定義
    def setUp(self):  # 共通する初期化処理メソッド定義
        self.data_path = pathlib.Path('/tmp/data')  # テストに利用する共通の設定を定義

    def tearDown(self):  # 共通で使う後処理メソッドを定義
        for p in self.data_path.iterdir():
            p.unlink()  # setUp()で作ったファイルを削除


class TestSample1(TestBase):  # TestBaseを親クラスとした子クラスを定義
    def setUp(self):  # 初期化処理メソッドを上書き
        super().setUp()  # super()関数で親クラスを呼び出し、親クラスのsetUp()メソッドを実行
        p1 = self.data_path / 'sample1.txt'
        p1.touch()  # テストで使うファイルを作る
        p2 = self.data_path / 'sample2.txt'
        p2.touch()  # テストで使うファイルの2個目を作る

    def test_two_files(self):  # テスト実行対象のメソッドを定義
        self.assertEqual(len(list(self.data_path.iterdir())), 2)


class TestSample2(TestBase):  # TestBaseを親クラスとした子クラスを定義
    def setUp(self):  # 初期化処理メソッドを上書き
        super().setUp()  # super()関数で親クラスを呼び出し、親クラスのsetUp()メソッドを実行
        p3 = self.data_path / 'sample3.txt'
        p3.touch()  # テストで使うファイルを作る

    def test_one_file(self):  # 新たなメソッドを定義し、テスト実行対象のメソッドとなる
        self.assertEqual(len(list(self.data_path.iterdir())), 1)
