>>> import math
>>> value = 'left align'
>>> f'|{value:<30}|'  # 文字列を左に寄せて、30文字になるようにスペースで埋める
'|left align                    |'
>>> value = 'right align'
>>> f'|{value:>30}|'  # 文字列を右に寄せて、30文字になるようにスペースで埋める
'|                   right align|'
>>> value = 'center'
>>> f'|{value:^30}|'  # 文字列を中央にそろえて、30文字になるようにスペースで埋める
'|            center            |'
>>> f'{value:-^30}'  # 文字列を中央にそろえて、30文字になるように「-」で埋める
'------------center------------'
>>> value = 1000
>>> f'{value:b} {value:o} {value:d} {value:x} {value:X}'  # 2進数、8進数、10進数、16進数（小文字）、16進数（大文字）に変換
'1111101000 1750 1000 3e8 3E8'
>>> f'{math.pi} {math.pi:f}'  # 「:f」で固定小数点数の文字列に変換
'3.141592653589793 3.141593'
>>> value = 0.045
>>> f'{value:%}'  # 百分率での表記に変換
'4.500000%'
>>> value = 10000000000000
>>> f'{value:,}'  # 数値に3桁ごとにカンマを挿入
'10,000,000,000,000'
>>> f'{math.pi:>5.2f}'  # 小数点以下が2桁になるよう変換し、文字列を右に寄せて全体が5桁になるようスペースで埋める
' 3.14'
>>> value = 0.045
>>> f'{value:>8.2%}'  # 小数点以下が2桁の百分率になるよう変換し、文字列を右に寄せて全体が8桁になるようスペースで埋める
'   4.50%'
>>> from datetime import datetime
>>> now = datetime.now()
>>> f'Today is {now:%Y-%m-%d}'  # 年月日に変換
'Today is 2021-06-06'
>>> f'Current time is {now:%H:%M:%S}'  # 時分秒に変換
'Current time is 23:01:21'
