>>> import io
>>> stream = io.StringIO("this is test\n")  # 初期値を渡すことができる
>>> stream.read(10)  # ストリームから指定サイズだけ読み出す
'this is te'
>>> stream.tell()  # 現在のオフセットを返す
10
>>> stream.seek(0, io.SEEK_END)  # オフセットをストリームの末尾に変更する
13
>>> stream.write('test')  # ストリームに文字列を書き込む
4
>>> print(stream.getvalue())  # ストリームが保持するすべての内容を返す
this is test
test
>>> stream.close()  # ストリームを閉じる
>>> stream.write('test')  # 閉じたあとに書き込もうとすると例外を送出する
Traceback (most recent call last):
  File "<stdin>", line 1, in <module>
ValueError: I/O operation on closed file
>>> with io.StringIO() as stream:  # withブロックを使うことで暗黙的にclose()を呼ぶこともできる
...     stream.write('test')
...
4
>>> the_zen_of_python = """The Zen of Python, by Tim Peters
... Beautiful is better than ugly.
... Explicit is better than implicit.
... Simple is better than complex.
... Complex is better than complicated.
... """
>>> stream = io.StringIO(the_zen_of_python)
>>> for line in stream:  # for文で1行ずつ読み込むこともできる
...     line
...
'The Zen of Python, by Tim Peters\n'
'Beautiful is better than ugly.\n'
'Explicit is better than implicit.\n'
'Simple is better than complex.\n'
'Complex is better than complicated.\n'
