>>> import io
>>> stream = io.BytesIO(b'abcdefg')  # 初期値を渡すことができる
>>> stream.read(5)  # ストリームから指定サイズだけ読み出す
b'abcde'
>>> stream.tell()  # 現在のオフセットを返す
5
>>> stream.seek(0, io.SEEK_END)  # オフセットをストリームの末尾に変更する
7
>>> stream.write(b'test')  # ストリームに文字列を書き込む
4
>>> print(stream.getvalue())  # ストリームが保持するすべての内容を返す
b'abcdefgtest'
>>> stream.close()  # ストリームを閉じる
>>> stream.write(b'test')  # 閉じたあとに書き込もうとすると例外を送出する
Traceback (most recent call last):
  File "<stdin>", line 1, in <module>
ValueError: I/O operation on closed file.
>>> with io.BytesIO() as stream:  # withブロックを使うことで暗黙的にclose()を呼ぶこともできる
...     stream.write(b'test')
...
4
>>> stream = io.BytesIO(b'abcdefg')
>>> view = stream.getbuffer()  # 読み込みおよび書き込みが可能なビューを返す
>>> view[2:4] = b'56'
>>> print(stream.getvalue())  # ビューの更新結果が反映される
b'ab56efg'
